==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate.md <==
# AwsIdentityAccessManagementAwsStsAlternate


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate')
```



| Illustration | AwsIdentityAccessManagementAwsStsAlternate | AwsIdentityAccessManagementAwsStsAlternateCard | AwsIdentityAccessManagementAwsStsAlternateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate.png) | ![illustration for AwsIdentityAccessManagementAwsStsAlternate](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate.Local.png) | ![illustration for AwsIdentityAccessManagementAwsStsAlternateCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternateCard.Local.png) | ![illustration for AwsIdentityAccessManagementAwsStsAlternateGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternateGroup.Local.png) |




## AwsIdentityAccessManagementAwsStsAlternate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsAlternate
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate')

' renders the element
AwsIdentityAccessManagementAwsStsAlternate('AwsIdentityAccessManagementAwsStsAlternate', 'Aws Identity Access Management Aws Sts Alternate', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsAlternate
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate')

' renders the element
AwsIdentityAccessManagementAwsStsAlternate('AwsIdentityAccessManagementAwsStsAlternate', 'Aws Identity Access Management Aws Sts Alternate', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementAwsStsAlternateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsAlternateCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate')

' renders the element
AwsIdentityAccessManagementAwsStsAlternateCard('AwsIdentityAccessManagementAwsStsAlternateCard', 'Aws Identity Access Management Aws Sts Alternate Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsAlternateCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate')

' renders the element
AwsIdentityAccessManagementAwsStsAlternateCard('AwsIdentityAccessManagementAwsStsAlternateCard', 'Aws Identity Access Management Aws Sts Alternate Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementAwsStsAlternateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsAlternateGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate')

' renders the element
AwsIdentityAccessManagementAwsStsAlternateGroup('AwsIdentityAccessManagementAwsStsAlternateGroup', 'Aws Identity Access Management Aws Sts Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsAlternateGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate')

' renders the element
AwsIdentityAccessManagementAwsStsAlternateGroup('AwsIdentityAccessManagementAwsStsAlternateGroup', 'Aws Identity Access Management Aws Sts Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate.md <==
# AwsIdentityAccessManagementAwsStsAlternate


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate')
```



| Illustration | AwsIdentityAccessManagementAwsStsAlternate | AwsIdentityAccessManagementAwsStsAlternateCard | AwsIdentityAccessManagementAwsStsAlternateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate.png) | ![illustration for AwsIdentityAccessManagementAwsStsAlternate](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate.Local.png) | ![illustration for AwsIdentityAccessManagementAwsStsAlternateCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternateCard.Local.png) | ![illustration for AwsIdentityAccessManagementAwsStsAlternateGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternateGroup.Local.png) |




## AwsIdentityAccessManagementAwsStsAlternate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsAlternate
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate')

' renders the element
AwsIdentityAccessManagementAwsStsAlternate('AwsIdentityAccessManagementAwsStsAlternate', 'Aws Identity Access Management Aws Sts Alternate', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsAlternate
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate')

' renders the element
AwsIdentityAccessManagementAwsStsAlternate('AwsIdentityAccessManagementAwsStsAlternate', 'Aws Identity Access Management Aws Sts Alternate', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementAwsStsAlternateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsAlternateCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate')

' renders the element
AwsIdentityAccessManagementAwsStsAlternateCard('AwsIdentityAccessManagementAwsStsAlternateCard', 'Aws Identity Access Management Aws Sts Alternate Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsAlternateCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate')

' renders the element
AwsIdentityAccessManagementAwsStsAlternateCard('AwsIdentityAccessManagementAwsStsAlternateCard', 'Aws Identity Access Management Aws Sts Alternate Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementAwsStsAlternateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsAlternateGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate')

' renders the element
AwsIdentityAccessManagementAwsStsAlternateGroup('AwsIdentityAccessManagementAwsStsAlternateGroup', 'Aws Identity Access Management Aws Sts Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsAlternateGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsAlternate')

' renders the element
AwsIdentityAccessManagementAwsStsAlternateGroup('AwsIdentityAccessManagementAwsStsAlternateGroup', 'Aws Identity Access Management Aws Sts Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
